package net.wanji.opt.synthesis.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import net.wanji.common.framework.rest.JsonViewObject;
import net.wanji.databus.dao.entity.GreenwaveRealtimePO;
import net.wanji.opt.synthesis.service.impl.StrategyGreenBeltServiceImpl;
import net.wanji.opt.vo.*;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.ws.rs.core.MediaType;
import java.util.Date;
import java.util.List;

/**
 * @author duanruiming
 * @date 2024/11/19 20:10
 * @description 神思推送绿波时序图
 */
@Api(value = "StrategyGreenBeltController", description = "策略绿波带")
@RequestMapping("/strategyBelt")
@RestController
public class StrategyGreenBeltController {

    @Resource
    private StrategyGreenBeltServiceImpl strategyGreenBeltService;

    @ApiOperation(value = "绿波时序图图形查询", notes = "绿波时序图图形查询", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @GetMapping(value = "/greenBeltChart")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = GreenBeltInfoVO.class),
    })
    public JsonViewObject greenBeltChart(Integer greenId) throws Exception {
        GreenBeltChartVO greenBeltChartVO = strategyGreenBeltService.selectChart(greenId, null);
        return JsonViewObject.newInstance().success(greenBeltChartVO);
    }


    @ApiOperation(value = "绿波停车次数排队长度", notes = "绿波停车次数排队长度", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @GetMapping(value = "/greenBeltStopTimeQueueLength")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = HotspotCrossVO.class),
    })
    public JsonViewObject greenBeltStopTimeQueueLength(Integer greenId) throws Exception {
        List<GreenBeltStopTimesQueueLengthVO> results = strategyGreenBeltService.greenBeltStopTimeQueueLength(greenId);
        return JsonViewObject.newInstance().success(results);
    }

    @ApiOperation(value = "绿波子区指标", notes = "绿波子区指标", response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @GetMapping(value = "/greenBeltAreaIndex")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = HotspotCrossVO.class),
    })
    public JsonViewObject greenBeltAreaIndex(Integer greenId) throws Exception {
        GreenwaveRealtimePO result = strategyGreenBeltService.greenBeltAreaIndex(greenId);
        return JsonViewObject.newInstance().success(result);
    }

}
